==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsCampaignSectionProductVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.math.BigDecimal;

/**
 * @author gongjun
 * @since 2016-07-17
 */
public class PsCampaignSectionProductVO extends PsBaseVO {

    private Long id;

    private Long campaignId;

    private Long campaignSectionId;

    private Long productId;

    private BigDecimal pricePrice;

    private Integer priceCount;

    private Integer limitCount;             // 最大数量，换购每单限购数、赠品每单赠送数

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCampaignId() {
        return campaignId;
    }

    public void setCampaignId(Long campaignId) {
        this.campaignId = campaignId;
    }

    public Long getCampaignSectionId() {
        return campaignSectionId;
    }

    public void setCampaignSectionId(Long campaignSectionId) {
        this.campaignSectionId = campaignSectionId;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public BigDecimal getPricePrice() {
        return pricePrice;
    }

    public void setPricePrice(BigDecimal pricePrice) {
        this.pricePrice = pricePrice;
    }

    public Integer getPriceCount() {
        return priceCount;
    }

    public void setPriceCount(Integer priceCount) {
        this.priceCount = priceCount;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }
}

==> pegasus-merchandise-api-2.4.5-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsCampaignSectionProductVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.math.BigDecimal;

/**
 * @author gongjun
 * @since 2016-07-17
 */
public class PsCampaignSectionProductVO extends PsBaseVO {

    private Long id;

    private Long campaignId;

    private Long campaignSectionId;

    private Long productId;

    private BigDecimal pricePrice;

    private Integer priceCount;

    /**
     * 最大数量，换购每单限购数、赠品每单赠送数
     */
    private Integer limitCount;

    /**
     * 排序权值
     */
    private Integer sort;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCampaignId() {
        return campaignId;
    }

    public void setCampaignId(Long campaignId) {
        this.campaignId = campaignId;
    }

    public Long getCampaignSectionId() {
        return campaignSectionId;
    }

    public void setCampaignSectionId(Long campaignSectionId) {
        this.campaignSectionId = campaignSectionId;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public BigDecimal getPricePrice() {
        return pricePrice;
    }

    public void setPricePrice(BigDecimal pricePrice) {
        this.pricePrice = pricePrice;
    }

    public Integer getPriceCount() {
        return priceCount;
    }

    public void setPriceCount(Integer priceCount) {
        this.priceCount = priceCount;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }
}
